SESSION_DIR = ".sessions"

UA = "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/129.0.0.0 Safari/537.36"
HEADERS = {
    "Accept": "*/*",
    "Accept-Language": "ja;q=0.8",
    "User-Agent": UA,
}
